@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:addr.c,v 1.33 1999/12/02 04:41:03 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:addr.c,v 1.34 2000/02/14 05:30:16 woods Exp"
  */
 
 /*
@@ -156,7 +156,7 @@ preparse_address_1(address, error, rest)
     if (*ap == '@') {
 	/* valid route-addr, not a mutant one */
 	ap = xmalloc((unsigned)(strlen(address) + 1));
-	(void) strcpy(ap, address);
+	strcpy(ap, address);
 	if (mark_end) {
 	    *mark_end++ = '>';		/* widden the original address */
 	}
@@ -176,7 +176,7 @@ preparse_address_1(address, error, rest)
 	}
 	if (*ap != '!') {
 	    ap = xmalloc((unsigned)(strlen(address) + 1));
-	    (void) strcpy(ap, address);
+	    strcpy(ap, address);
 	    if (mark_end) {
 		*mark_end++ = '>';	/* widden the original address */
 	    }
@@ -190,7 +190,7 @@ preparse_address_1(address, error, rest)
 	    register char *p = xmalloc((unsigned)strlen(address));
 	    DEBUG(DBG_ADDR_MID, "found host!(host!)*@route form--ugh!\n");
 	    /* first part already !-route */
-	    (void) strncpy(p, address, (size_t) (ap - address));
+	    strncpy(p, address, (size_t) (ap - address));
 	    if (mark_end) {
 		*mark_end++ = '>';	/* widden the original address */
 	    }
@@ -199,7 +199,7 @@ preparse_address_1(address, error, rest)
 		DEBUG(DBG_ADDR_MID, "preparse_address returns: (null)\n");
 		return NULL;
 	    }
-	    (void) strcat(p, ap);	/* concatenate together */
+	    strcat(p, ap);		/* concatenate together */
 	    xfree(ap);
 	    DEBUG1(DBG_ADDR_HI, "preparse_address returns: %s\n", p);
 	    *rest = mark_end;
@@ -207,7 +207,7 @@ preparse_address_1(address, error, rest)
 	}
     }
     ap = xmalloc((unsigned)(strlen(address) + 1));
-    (void) strcpy(ap, address);
+    strcpy(ap, address);
     if (mark_end) {
 	*mark_end++ = '>';	/* widden the original address */
     }
@@ -694,7 +694,7 @@ internal_build_uucp_route(address, error, partial, flag)
      * XXX this seems to be bogus....
      */
     storage = remainder = xmalloc((unsigned)(strlen(address) + 1));
-    (void)strcpy(storage, address);
+    strcpy(storage, address);
 
     /* initialize for copy into string region */
     STR_INIT(sp);
@@ -1582,66 +1582,73 @@ main(argc, argv)
      */
     if (argc > 1) {
 	while (*++argv) {
-	    (void)fprintf(stderr, "input:  %s\n", *argv);
+	    fprintf(stderr, "input:  <%s>\n", *argv);
 
 	    /* preparse the address to get rid of mutant forms */
 	    addr = preparse_address(*argv, &error);
 	    if (addr) {
-		(void)fprintf(stderr, "preparse_address: %s\n", addr);
+		fprintf(stderr, "preparse_address: %s\n", addr);
 	    } else {
-		(void)fprintf(stderr, "preparse_address: %s\n", error);
+		fprintf(stderr, "preparse_address: %s\n", error);
 		break;
 	    }
 
 	    /* see what build_uucp_route yields */
 	    s = build_uucp_route(addr, &error, 0);
 	    if (s) {
-		(void)fprintf(stderr, "build_uucp_route: %s\n", s);
+		fprintf(stderr, "build_uucp_route: %s\n", s);
 	    } else {
-		(void)fprintf(stderr, "build_uucp_route: %s\n", error);
+		fprintf(stderr, "build_uucp_route: %s\n", error);
 	    }
 
 	    /* see what parse_address yields */
 	    form = parse_address(addr, &target, &remainder, (int *)0);
 	    if (form == LOCAL) {
-		(void)printf("LOCAL %s\n", remainder);
+		printf("LOCAL %s\n", remainder);
 	    } else if (form == FAIL) {
-		(void)fprintf(stderr, "parse_address: %s\n", remainder);
+		fprintf(stderr, "parse_address: %s\n", remainder);
 	    } else {
-		(void)printf("REMOTE %s@%s\n", remainder, target);
+		printf("REMOTE %s@%s\n", remainder, target);
 	    }
 	}
     } else {
 	char *line;
 
 	while ((line = read_line(stdin))) {
-	    (void)fprintf(stderr, "input:  %s\n", line);
+	    int len;
+
+	    /* trim the trailing newline, if any */
+	    len = strlen(line);
+	    if (line[len - 1] == '\n') {
+		line[len - 1] = '\0';
+	    }
+	    fprintf(stderr, "input:  <%s>\n", line);
 
 	    /* preparse the address to get rid of mutant forms */
 	    addr = preparse_address(line, &error);
 	    if (addr) {
-		(void)fprintf(stderr, "preparse_address: %s\n", addr);
+		fprintf(stderr, "preparse_address: %s\n", addr);
 	    } else {
-		(void)fprintf(stderr, "preparse_address: %s\n", error);
+		fprintf(stderr, "preparse_address: %s\n", error);
 		break;
 	    }
 
 	    /* see what build_uucp_route yields */
 	    s = build_uucp_route(addr, &error, 0);
 	    if (s) {
-		(void)fprintf(stderr, "build_uucp_route: %s\n", s);
+		fprintf(stderr, "build_uucp_route: %s\n", s);
 	    } else {
-		(void)fprintf(stderr, "build_uucp_route: %s\n", error);
+		fprintf(stderr, "build_uucp_route: %s\n", error);
 	    }
 
 	    /* see what parse_address yields */
 	    form = parse_address(addr, &target, &remainder, (int *)0);
 	    if (form == LOCAL) {
-		(void)printf("LOCAL %s\n", remainder);
+		printf("LOCAL %s\n", remainder);
 	    } else if (form == FAIL) {
-		(void)fprintf(stderr, "parse_address: %s\n", remainder);
+		fprintf(stderr, "parse_address: %s\n", remainder);
 	    } else {
-		(void)printf("REMOTE %s@%s\n", remainder, target);
+		printf("REMOTE %s@%s\n", remainder, target);
 	    }
 	}
     }
