@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:alloc.c,v 1.17 2000/02/05 19:07:24 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:alloc.c,v 1.18 2000/02/17 03:53:36 woods Exp"
  */
 
 /*
@@ -213,6 +213,7 @@ brealloc(data, size, block)
     for (oldseg=block->next;
 	 oldseg != NULL && oldseg->data != data;
 	 oldseg=oldseg->next) {
+	; /* NO-OP */
     }
     if (oldseg == NULL) {
 	panic(EX_SOFTWARE, 
@@ -256,27 +257,35 @@ bfree(data, block)
 	/* NOTREACHED */
     }
 
-    /* delete the segment from the block */
-    for (lastseg=NULL, oldseg=block->next; 
-	 oldseg!=NULL && oldseg->data!=data;
-	 lastseg=oldseg, oldseg=oldseg->next) {
+    /*
+     * delete the segment from the block
+     */
+    /* first find the segment */
+    for (lastseg = NULL, oldseg = block->next; 
+	 oldseg != NULL && oldseg->data != data;
+	 lastseg = oldseg, oldseg = oldseg->next) {
+	; /* NO-OP */
     }
     if (oldseg == NULL) {
 	panic(EX_SOFTWARE, 
-	    "bfree: data (at 0x%lx) not in block (at 0x%lx, cnt: %d)",
-	    (long)data, (long)block, block->cnt);
+	      "bfree: data (at 0x%lx) not in block (at 0x%lx, cnt: %d)",
+	      (long) data, (long) block, block->cnt);
 	/* NOTREACHED */
     }
+    /* remove the segment from the block */
     if (lastseg == NULL) {
 	block->next = oldseg->next;
     } else {
 	lastseg->next = oldseg->next;
     }
+    /* do the accounting */
     --block->cnt;
 
     /* free the data and segment */
     (void) free(oldseg->data);
-    (void) free((char *)oldseg);
+    (void) free((char *) oldseg);
+
+    return;
 }
 
 
@@ -285,7 +294,7 @@ bfree(data, block)
  *
  * Start a new storage block with no storage allociated with it.
  *
- * NOTE: the block structore becomes a segment from the master block
+ * NOTE: the block structure becomes a segment in the master block
  *
  * input:
  *	none
@@ -330,17 +339,22 @@ realloc_block(data, oldblock, newblock)
 	/* NOTREACHED */
     }
 
-    /* delete the segment from the oldblock */
-    for (lastseg=NULL, oldseg=oldblock->next; 
-	 oldseg!=NULL && oldseg->data!=data;
-	 lastseg=oldseg, oldseg=oldseg->next) {
+    /*
+     * delete the segment from the oldblock
+     */
+    /* first find the segment */
+    for (lastseg = NULL, oldseg = oldblock->next; 
+	 oldseg != NULL && oldseg->data != data;
+	 lastseg = oldseg, oldseg = oldseg->next) {
+	; /* NO-OP */
     }
     if (oldseg == NULL) {
 	panic(EX_SOFTWARE, 
-	    "realloc_block: data (at 0x%lx) not in block (at 0x%lx, cnt: %d)",
-	    (long)data, (long)oldblock, oldblock->cnt);
+	      "realloc_block: data (at 0x%lx) not in block (at 0x%lx, cnt: %d)",
+	      (long)data, (long)oldblock, oldblock->cnt);
 	/* NOTREACHED */
     }
+    /* remove the segment from the old block */
     if (lastseg == NULL) {
 	oldblock->next = oldseg->next;
     } else {
@@ -352,6 +366,8 @@ realloc_block(data, oldblock, newblock)
     oldseg->next = newblock->next;
     newblock->next = oldseg; 
     ++newblock->cnt;
+
+    return;
 }
 
 /*
@@ -362,33 +378,40 @@ realloc_block(data, oldblock, newblock)
  */
 void
 free_block(block)
-    struct block *block;	/* the new to free all segments on */
+    struct block *block;	/* the block to free */
 {
-    struct bseg *oldseg;	/* the segement to free */
+    struct bseg *curseg;
 
-    /* firewall */
     if (block == NULL) {
 	panic(EX_SOFTWARE, "free_block: block is NULL");
 	/* NOTREACHED */
     }
 
     /* free the chain */
-    for(oldseg = block->next; 
-	block->cnt > 0 && block->next != NULL;
-	--block->cnt, block->next = oldseg->next) {
+    curseg = block->next;
+    while (curseg != NULL) {
+	struct bseg *nextseg;
 
-	/* free the data */
-	(void) free(block->next->data);
-	/* free the segemtn */
-	(void) free((char *)block->next);
+	/* find the next entry so we can free the current one */
+	nextseg = curseg->next;
+	/* do the accounting */
 	--block->cnt;
+	/* free the data */
+	(void) free(curseg->data);
+	/* free the segemnt */
+	(void) free((char *) curseg);
+	/* go on to the next */
+	curseg = nextseg;
     }
 
-    /* firewall */
-    if (block->cnt != 0 || block->next != NULL) {
-	panic(EX_SOFTWARE, 
-	  "free_block: freed block (at 0x%lx) has cnt:%d, next:0x%lx",
-	  (long)block, block->cnt, (long)block->next);
+    /* double-check the balance sheet */
+    if (block->cnt != 0) {
+	panic(EX_SOFTWARE, "free_block: freed block (at 0x%lx) has cnt:%d", (long) block, block->cnt);
 	/* NOTREACHED */
     }
+
+    /* free the block segment from the master block */
+    bfree(block, &master);
+
+    return;
 }
