@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:field.c,v 1.13 2000/02/05 19:09:00 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:field.c,v 1.14 2000/02/14 05:30:25 woods Exp"
  */
 
 /*
@@ -1593,7 +1593,14 @@ main(argc, argv)
 	char *line;
 
 	while ((line = read_line(stdin))) {
-	    (void)fprintf(stderr, "input:  %s\n", line);
+	    int len;
+
+	    /* trim the trailing newline, if any */
+	    len = strlen(line);
+	    if (line[len - 1] == '\n') {
+		line[len - 1] = '\0';
+	    }
+	    (void)fprintf(stderr, "input:  <%s>\n", line);
 	    s = index(line, ':');
 	    if (s) {
 		s++;
