@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:hash.c,v 1.14 2000/02/06 16:32:07 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:hash.c,v 1.16 2000/02/17 03:54:44 woods Exp"
  */
 
 /*
@@ -33,8 +33,11 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <ctype.h>
-#include "smail.h"
 #include "defs.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+#include "smail.h"
 #include "exitcodes.h"
 #include "hash.h"
 #include "alloc.h"
@@ -50,14 +53,18 @@ static struct hash *new_hash_element();
 
 #ifdef STANDALONE
 int debug = 0;	/* default debug level is NONE */
-#define errfile stderr
-void panic();
-#define xmalloc(x) (malloc(x))	/* naive allocator */
-#define bmalloc(x,y) (malloc(x))	/* naive allocator */
-char *malloc();
-#define xfree(x) (free(x))	/* naive deallocator */
-#define bfree(x,y) (free(x))	/* naive deallocator */
-void free();
+# define errfile stderr
+extern void panic();
+# define xmalloc(x) (malloc(x))		/* naive allocator */
+# define bmalloc(x,y) (malloc(x))	/* naive allocator */
+# define xfree(x) (free(x))		/* naive deallocator */
+# define bfree(x,y) (free(x))		/* naive deallocator */
+/* functions imported by this file */
+# if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
+extern char *malloc();
+extern char *realloc();
+extern void free();				/* int on SunOS */
+# endif
 #endif	/* STANDALONE */
 
 /*
@@ -500,6 +507,9 @@ free_hash_table(table)
 	DEBUG(DBG_HASH_LO, "free_hash_table(): about to panic() with NULL block\n");
     }
     bfree(table, table->life);
+
+    /* XXX why don't we free 'table' itself?  or free_block() it? */
+
     return;
 }
 
@@ -1067,13 +1077,37 @@ write_hash_table(table, stream)
 
 #ifdef STANDALONE
 
-#include "dys.h"
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <limits.h>
+#include "dys.h"
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
-#define TABLE_LEN 3 /* use only a few slots to stress the chain code */
+#ifdef USE_VMALLOC
+# include <vmalloc.h>
+# define malloc_check()	vmdbcheck(Vmheap)
+#endif
 
-char *tempname = "/tmp/hashtestXXXXXX";	/* tempory hash file name */
+#if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
+extern char *mktemp();
+#endif
+
+#ifndef malloc_check
+# define malloc_check()	/* NO-OP */
+#endif
+
+#if !defined(SIZE_T_MAX) && defined(USHRT_MAX)
+# define SIZE_T_MAX	UINT_MAX	/* most modern systems use UINT_MAX */
+#elif !defined(SIZE_T_MAX)
+# define SIZE_T_MAX	0xffffffffU	/* XXX is 'U' a valid suffix in traditional C? */
+#endif
+
+#define TABLE_LEN	3		/* use only a few slots to stress the chain code */
+
+int return_to_sender = FALSE;
+char *tempname = "/tmp/smhtXXXXXX";	/* tempory hash file name */
 
 void
 main(argc, argv)
@@ -1083,6 +1117,8 @@ main(argc, argv)
     int i;			/* index */
     char *buf;			/* the input buffer for stdin args */
     struct hash *cur;		/* pointer to walk the table */
+    struct block *table_block;	/* bmalloc() for bfree() */
+    struct block *tableic_block; /* bmalloc() for bfree() */
     struct hash_table *table;	/* our allocated table */
     struct hash_table *tableic;	/* allocated table without regard to case */
     void test();		/* test an with an element */
@@ -1093,7 +1129,7 @@ main(argc, argv)
      * establish debug level
      */
     DEBUG(DBG_HASH_LO, "main: start\n");
-    if (argc > 1 && strncmp(argv[1], "-d", 2) == 0) {
+    if (argc > 1 && strncmp(argv[1], "-v", 2) == 0) {
 	    /* we have a debug level, use it */
 	    if (argv[1][2] != '\0') {
 		    debug = atoi(&argv[1][2]);
@@ -1110,26 +1146,33 @@ main(argc, argv)
     /*
      * setup a hash table
      */
-    table = new_hash_table(TABLE_LEN, (struct block *)NULL, HASH_CASEFOLD);
-    tableic = new_hash_table(TABLE_LEN, (struct block *)NULL, 0);
+    table_block = malloc_block();
+    table = new_hash_table(TABLE_LEN, table_block, HASH_CASEFOLD);
+    tableic_block = malloc_block();
+    tableic = new_hash_table(TABLE_LEN, tableic_block, 0);
 
     /*
      * special case: no args means read one arg per line
      */
     if (argc == 1) {
 	while ((buf = read_line(stdin))) {
-	    i = strlen(buf);
-	    buf[i-1] = '\0';
+	    int len;
+
+	    /* trim the trailing newline, if any */
+	    len = strlen(buf);
+	    if (buf[len - 1] == '\n') {
+		buf[len - 1] = '\0';
+	    }
 	    DEBUG1(DBG_HASH_LO,
 		   "main: testing <%s> -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-\n", buf);
 	    test(buf, table);
-	    if ( debug >= DBG_HASH_HI ) {
+	    if (debug >= DBG_HASH_HI) {
 		dump_hash_table(table);
 	    }
 	    DEBUG1(DBG_HASH_LO,
 		   "main: testing ignore case <%s> -*-*-*-*-*-*-*-*-*-\n", buf);
 	    test(buf, tableic);
-	    if ( debug >= DBG_HASH_HI ) {
+	    if (debug >= DBG_HASH_HI) {
 		dump_hash_table(tableic);
 	    }
 	}
@@ -1138,17 +1181,17 @@ main(argc, argv)
      * hash each argument
      */
     } else {
-	for (i=1; i < argc; ++i) {
+	for (i = 1; i < argc; ++i) {
 	    DEBUG1(DBG_HASH_LO,
 		   "main: testing <%s> -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-\n", buf);
 	    test(argv[i], table);
-	    if ( debug >= DBG_HASH_HI ) {
+	    if (debug >= DBG_HASH_HI) {
 		dump_hash_table(table);
 	    }
 	    DEBUG1(DBG_HASH_LO,
 		   "main: testing ignore case <%s> -*-*-*-*-*-*-*-*-*-\n", buf);
 	    test(argv[i], tableic);
-	    if ( debug >= DBG_HASH_HI ) {
+	    if (debug >= DBG_HASH_HI) {
 		dump_hash_table(tableic);
 	    }
 	}
@@ -1167,21 +1210,29 @@ main(argc, argv)
      */
     DEBUG(DBG_HASH_LO, "main: free memory\n");
     /* free the hash table elements */
-    for (cur=walk_hash((struct hash *)NULL,table);
-	 cur != NULL;
-	 cur=walk_hash(cur,table))
-    {
-	free_hash_element(cur, 0, table); /* free without deletion */
+    cur = walk_hash((struct hash *) NULL, table);
+    while (cur) {
+	struct hash *next;		/* pointer to the next element */
+
+	next = walk_hash(cur, table);	/* find the next entry */
+	free_hash_element(cur, 0, table); /* free the current without deletion */
+	cur = next;
     }
-    free_hash_table(table);	/* free up the memory */
+    free_hash_table(table);	/* free up the header memory */
+    free_block(table_block);
+
     DEBUG(DBG_HASH_LO, "main: free memory ignore case\n");
-    for (cur=walk_hash((struct hash *)NULL,tableic);
-	 cur != NULL;
-	 cur=walk_hash(cur,tableic))
-    {
-	free_hash_element(cur, 0, tableic); /* free without deletion */
+    cur = walk_hash((struct hash *) NULL, tableic);
+    while (cur) {
+	struct hash *next;		/* pointer to the next element */
+
+	next = walk_hash(cur, tableic);	/* find the next entry */
+	free_hash_element(cur, 0, tableic); /* free the current without deletion */
+	cur = next;
     }
-    free_hash_table(tableic);	/* free up the memory */
+    free_hash_table(tableic);	/* free up the header memory */
+    free_block(tableic_block);
+
     DEBUG(DBG_HASH_LO, "main: end\n");
     exit(EX_OK);
 }
@@ -1309,20 +1360,20 @@ dump_hash_table(table)
     /*
      * check the hash chains
      */
-    for (i=0; i < TABLE_LEN; ++i) {
+    for (i = 0; i < TABLE_LEN; ++i) {
 	DEBUG1(DBG_HASH_HI, "dump: slot[%d]:", i);
 	/* check for empty slots */
 	if (empty_slot(table->slot[i])) {
 	    DEBUG(DBG_HASH_HI, "Empty\n");
 	    continue;
 	}
-	for (cur=table->slot[i]; cur != NULL; cur=next_hash(cur, table)) {
+	for (cur = table->slot[i]; cur; cur = next_hash(cur, table)) {
 	    if (cur->keylen == 0) {
 		DEBUG2(DBG_HASH_HI, " 0x%lx: <%s> :EOC ",
-		   (long)cur, cur->keystr);
+		       (long) cur, cur->keystr);
 	    } else {
 		DEBUG3(DBG_HASH_HI, " 0x%lx: <%s> :0x%lx ",
-		   (long)cur, cur->keystr, (long)cur->succ);
+		       (long) cur, cur->keystr, (long)cur->succ);
 	    }
 	}
 	DEBUG(DBG_HASH_HI, "\n");
@@ -1344,7 +1395,7 @@ hash_file_test(table)
     int caseflag;		/* 0 ==> use strcmp, 1 ==> strcmpic */
     char *template;		/* template for mktemp */
     FILE *stream;		/* the file stream */
-    char *mktemp();		/* form a temp filename */
+    int table_len;		/*  */
 
     /*
      * open up a file to perform hash table operations into
@@ -1353,9 +1404,8 @@ hash_file_test(table)
     strcpy(template, tempname);
     filename = mktemp(template);
     DEBUG1(DBG_HASH_LO, "hash_file_test: using <%s>\n", filename);
-    stream = fopen(filename, "w");
-    if (stream == NULL) {
-	panic(EX_CANTCREAT, "hash_file_test: can not creat <%s>", filename);
+    if (! (stream = fopen(filename, "w"))) {
+	panic(EX_CANTCREAT, "hash_file_test: can not fopen(%s, 'w'): %s", filename, strerror(errno));
     }
 
     /*
@@ -1363,23 +1413,27 @@ hash_file_test(table)
      */
     write_hash_table(table, stream);
     if (fclose(stream) != 0) {
-	panic(EX_IOERR, "hash_file_test: can not fclose\n");
+	panic(EX_IOERR, "hash_file_test: can not fclose(): %s", strerror(errno));
     }
 
     /*
      * reread the hash table into memory
      */
     DEBUG1(DBG_HASH_MID, "hash_file_test: rereading <%s>\n", filename);
-    stream = fopen(filename, "r");
-    if (stream == NULL) {
-	panic(EX_CANTCREAT, "hash_file_test: can not reopen <%s>", filename);
+    if (! (stream = fopen(filename, "r"))) {
+	panic(EX_NOINPUT, "hash_file_test: can not fopen(%s, 'r'): %s", filename, strerror(errno));
     }
     if (fstat(fileno(stream), &buf) < 0) {
-	panic(EX_IOERR, "hash_file_test: can not stat <%s>", filename);
+	panic(EX_IOERR, "hash_file_test: can not fstat(%s): ", filename, strerror(errno));
     }
-    table2 = (struct hash_table *)xmalloc(buf.st_size * sizeof(char));
-    if (fread((char *)table2,sizeof(char),buf.st_size,stream) != buf.st_size) {
-	panic(EX_IOERR, "hash_file_test: can not reread <%s>", filename);
+    if (buf.st_size > SIZE_T_MAX) {
+	panic(EX_IOERR, "hash_file_test: file <%s> too big to read! (%ld)", filename, (long) buf.st_size);
+    }
+    table_len = buf.st_size;
+    DEBUG2(DBG_HASH_LO, "hash_file_test: about to allocate %d bytes to be read from %s.\n", table_len, filename)
+    table2 = (struct hash_table *) xmalloc(table_len * sizeof(char));
+    if (fread((char *) table2, sizeof(char), table_len, stream) != table_len) {
+	panic(EX_IOERR, "hash_file_test: can not fread(%s): %s", filename, strerror(errno));
     }
 
     /*
@@ -1387,13 +1441,13 @@ hash_file_test(table)
      */
     caseflag = table->flags & HASH_CASEFOLD;
     DEBUG(DBG_HASH_MID, "hash_file_test: verify\n");
-    for (cur=walk_hash((struct hash *)NULL,table),
-	 	cur2=walk_hash((struct hash *)NULL,table2);
-	 cur != NULL || cur2 != NULL;
-	 cur=walk_hash(cur,table), cur2=walk_hash(cur2,table2))
-    {
-	    /* compare cur and cur2 */
-	    if (stringcmp(cur->keystr,cur2->keystr,caseflag) != 0) {
+    for (cur = walk_hash((struct hash *) NULL, table), cur2 = walk_hash((struct hash *) NULL, table2);
+	 cur && cur2;
+	 cur = walk_hash(cur, table), cur2 = walk_hash(cur2, table2)) {
+	    /*
+	     * compare cur and cur2
+	     */
+	    if (stringcmp(cur->keystr, cur2->keystr, caseflag) != 0) {
 		panic(EX_SOFTWARE,
 		      "hash_file_test: key mismatch: <%s> != <%s>\n",
 		      cur->keystr, cur2->keystr);
@@ -1409,7 +1463,12 @@ hash_file_test(table)
 		      cur->keystr, cur2->keystr);
 	    }
     }
-
+    if (cur != NULL && cur2 != NULL) {
+	panic(EX_SOFTWARE,
+	      "hash_file_test: %s longer than %s!\n",
+	      cur ? "cur" : "cur2",
+	      cur ? "cur2" : "cur");
+    }
     /*
      * cleanup
      */
