@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:log.c,v 1.34 2000/02/06 16:32:24 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:log.c,v 1.35 2000/02/14 05:29:34 woods Exp"
  */
 
 /*
@@ -292,7 +292,7 @@ open_msg_log()
 	    (void) mkdir("msglog", auto_mkdir_mode);
 	} else {
 	    /* alternate idea, permissions wrong so try to remove it */
-	    (void) unlink(panic_fn);
+	    (void) unlink(msg_log_fn);
 	}
 #ifdef	O_APPEND
 	fd = open(msg_log_fn, O_CREAT|O_APPEND|O_WRONLY, log_mode);
@@ -702,7 +702,14 @@ send_log(f, all, banner)
 	return;
     }
     /* copy from message-log to the specified file */
-    while ((mln = read_line(mlog)) && *mln) {
+    while ((mln = read_line(mlog))) {
+	int len;
+
+	/* trim the trailing newline, if any */
+	len = strlen(mln);
+	if (mln[len - 1] == '\n') {
+	    mln[len - 1] = '\0';
+	}
 	if (!all && *mln == 'X') {
 	    lastx = TRUE;
 	    continue;
