@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:main.c,v 1.54 2000/02/11 04:49:33 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:main.c,v 1.57 2000/02/17 04:39:15 woods Exp"
  */
 
 /*
@@ -850,24 +850,20 @@ initialize_state()
     sender_is_trusted = TRUE;
     dont_deliver = FALSE;
 
-    /*
-     * generate a new address hit table where case is ignored and
-     * all data resides in memory
-     */
-    if (!hit_table_block) {
-	hit_table_block = malloc_block();
-    }
-    if (hit_table) {
-	struct hash *curh;		/* pointer to walk the table */
+    reset_hit_table();
+}
 
-	/* free the hash table elements */
-	for (curh = walk_hash((struct hash *) NULL, hit_table);
-	     curh;
-	     curh = walk_hash(curh, hit_table)) {
-	    free_hash_element(curh, 0, hit_table); /* free without deletion */
-	}
-	free_hash_table(hit_table);
+/*
+ * generate a new address hit table where case is ignored and all data resides
+ * in memory
+ */
+void
+reset_hit_table()
+{
+    if (hit_table_block) {
+	free_block(hit_table_block);
     }
+    hit_table_block = malloc_block();
     hit_table = new_hash_table(hit_table_len,
 			       hit_table_block,
 			       HASH_DEFAULT);
