@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:modes.c,v 1.97 2000/02/07 15:28:21 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:modes.c,v 1.98 2000/02/14 05:30:39 woods Exp"
  */
 
 /*
@@ -435,7 +435,7 @@ test_addresses()
 	int form = FAIL;
 	char *lp;
 
-	if (!*(lp = read_line(stdin))) {
+	if (!(lp = read_line(stdin))) {
 	    break;
 	}
 	strip_rfc822_comments(lp);
