@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:parse.c,v 1.7 1999/11/29 21:11:12 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:parse.c,v 1.8 2000/02/17 04:22:54 woods Exp"
  */
 
 /*
@@ -20,7 +20,8 @@
  *	method and config files are the same, so routines for parsing
  *	these files is given as well.
  *
- *	external functions:  read_entry, parse_entry, parse_config.
+ *	external functions:  parse_entry, parse_config, parse_table,
+ *	read_entry.
  */
 #ifdef STANDALONE
 # define xmalloc malloc
@@ -405,9 +406,13 @@ finish_parse(tokens, generic, driver)
 /*
  * parse_config - parse config file name/value pairs
  *
- * given a string, such as returned by read_entry, turn it into
- * a single attribute entry.  On error, return NULL, with an
- * error message in *error.
+ * given a string, such as returned by read_entry, turn it into a single
+ * attribute entry with the "name" field pointing at the start of the config
+ * attribute name and with the "value" field pointing at the attribute's value.
+ * Both are pointing at the same allocated storage block and can be freed by
+ * passing the "name" pointer to xfree().
+ *
+ * On error, return NULL, with an error message in *error.
  */
 struct attribute *
 parse_config(entry, error)
@@ -540,7 +545,10 @@ parse_config(entry, error)
  *
  *	string1		string2
  *
- * returned attribute has string1 as name and string2 as value.
+ * the returned "struct attribute" its "name" field pointing at the beginning
+ * of string1 and its "value" field pointing at the beginning of string2.  Both
+ * are pointing at the same allocated storage block and can be freed by passing
+ * the "name" pointer to xfree().
  */
 struct attribute *
 parse_table(entry, error)
