@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:resolve.c,v 1.20 2000/02/06 16:36:48 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:resolve.c,v 1.23 2000/02/17 04:39:55 woods Exp"
  */
 
 /*
@@ -42,8 +42,8 @@
 #endif
 
 /* exported variables */
-struct hash_table *hit_table;		/* table to recognize address hits */
-struct block *hit_table_block;		/* bmalloc() for bfree() */
+struct hash_table *hit_table = NULL;	/* table to recognize address hits */
+struct block *hit_table_block = NULL;	/* block() for bmalloc() et al */
 
 
 /*
@@ -199,7 +199,7 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
     if (hash_addrs) {
 	struct addr *prev;
 	struct hash_table *hit_out_table; /* table to recognize address hits */
-	struct block *hit_out_table_block; /* bmalloc() for bfree() */
+	struct block *hit_out_table_block; /* block for bmalloc() et al */
 	struct hash *curh;		/* pointer to walk the table */
 	char *hashval;
 
@@ -230,14 +230,10 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
 	    }
 	    xfree(hashval);
 	}
-	/* free the hash table elements */
-	for (curh = walk_hash((struct hash *) NULL, hit_table);
-	     curh;
-	     curh = walk_hash(curh, hit_table)) {
-	    free_hash_element(curh, 0, hit_table); /* free without deletion */
-	}
-	free_hash_table(hit_out_table);
+	/* free everything */
+	free_block(hit_out_table_block);
     }
+
     return;
 }
 
