@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:retry.c,v 1.39 2000/02/11 04:48:01 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:retry.c,v 1.41 2000/02/17 04:29:52 woods Exp"
  */
 
 /*
@@ -176,7 +176,7 @@ read_retry_file()
 	if (p == NULL) {
 	    error = xprintf("%s: %s: invalid entry, no '/': %s.", retry_file, new->name, new->value);
 	    xfree(new->name);
-	    xfree(new->value);
+	    /* note that new->value points to the same storage as new->name */
 	    xfree((char *) new);
 	    break;
 	}
@@ -190,7 +190,6 @@ read_retry_file()
 	    if (interval < 0) {
 		error = xprintf("%s: %s: invalid retry interval: %s.", retry_file, new->name, new->value);
 		xfree(new->name);
-		xfree(new->value);
 		xfree((char *) new);
 		break;
 	    }
@@ -204,7 +203,6 @@ read_retry_file()
 	    if (duration < 0) {
 		error = xprintf("%s: %s: invalid retry duration: %s.", retry_file, new->name, p);
 		xfree(new->name);
-		xfree(new->value);
 		xfree((char *) new);
 		break;
 	    }
@@ -216,8 +214,8 @@ read_retry_file()
 	r = (struct retry *) xmalloc(sizeof(struct retry));
 
 	/* assign new structure's domain */
-	/* note we keep the allocated storage from parse_table() */
-	r->domains = new->name;
+	/* shrink the storage from parse_table() to toss the "value" part */
+	r->domains = xrealloc(new->name, strlen(new->name));
 
 	/* assign new structure's limits */
 	r->interval = interval;
@@ -235,11 +233,10 @@ read_retry_file()
 	/* free record and value returned by parse_table() but don't free the
          * name as we're using it in the retry record above
 	 */
-	xfree(new->value);
 	xfree((char *) new);
 
-	/* a wildcard record obviates need to read further */
-	if (*nr->domains == '*') {
+	/* a lone wildcard record obviates need to read further */
+	if (EQ(nr->domains, "*")) {
 	    break;
 	}
     }
@@ -249,7 +246,7 @@ read_retry_file()
      * if no errors, and there is no default record, and if
      * global configuration requires a default record, add it.
      */
-    if (!error && (!nr && (*(nr->domains) != '*')) && (r = default_retry())) {
+    if (!error && nr && EQ(nr->domains, "*") && (r = default_retry())) {
 	if (nr == NULL) {
 	    retries = r;
 	} else {
