@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:smtprecv.c,v 1.112 2000/02/11 16:15:10 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:smtprecv.c,v 1.115 2000/02/17 04:36:18 woods Exp"
  */
 
 /*
@@ -118,7 +118,6 @@ static void send_session_denied_reply(FILE *, char *, char *);
 static void non_compliant_reply(FILE *, int, char *, char *);
 static void illegal_operand_warning(char *, char *operand);
 static void reset_state(void);
-static void reset_hit_table(void);
 static enum e_smtp_commands read_smtp_command(FILE *, FILE *);
 static int decode_mail_options(char *, FILE *);
 static void expand_addr(char *, FILE *);
@@ -143,7 +142,6 @@ static void send_session_denied_reply();
 static void non_compliant_reply();
 static void illegal_operand_warning();
 static void reset_state();
-static void reset_hit_table();
 static enum e_smtp_commands read_smtp_command();
 static int decode_mail_options();
 static void expand_addr();
@@ -733,6 +731,10 @@ receive_smtp(in, out)
 	    }
 	    /* don't be fussy about headers, use msg_body_size instead of msg_size */
 	    if (max_message_size > 0 && msg_body_size > max_message_size) {
+		/* XXX should this be response-rate limited? */
+#ifdef NO_LOG_SMTP_TOO_BIG		/* only log when ESMTP SIZE was ignored */
+		if (accepted_msg_size > 0 && accepted_msg_size != -1) {
+#else
 		write_log(WRITE_LOG_SYS, "remote DATA: message too big%s (body %ld bytes) from %s%s%s%s%s%s%s%s%s.",
 			  (accepted_msg_size > 0 && accepted_msg_size != -1) ? ", client ignored ESMTP SIZE" : "",
 			  msg_body_size,
@@ -745,10 +747,15 @@ receive_smtp(in, out)
 			  sender_host_addr ? " [" : "",
 			  sender_host_addr ? sender_host_addr : "",
 			  sender_host_addr ? "]" : "");
+#endif
+#ifdef NO_LOG_SMTP_TOO_BIG
+		}
+#endif
 		log_spool_errors();
 		unlink_spool();
 		if (out) {
 		    fprintf(out, "552-5.3.4 Message too big for system.\r\n");
+		    /* NOTE: the remainder of this reply is identical in two places */
 		    fprintf(out, "552-5.3.4 Do NOT send files by e-mail!\r\n");
 		    fprintf(out, "552-5.3.4 If you are sending a MIME message please set your mailer so that it\r\n");
 		    fprintf(out, "552-5.3.4 splits messages larger than 64KB into muliple parts.\r\n");
@@ -885,6 +892,7 @@ receive_smtp(in, out)
 	case DEBUG_CMD: {
 	    int temp = 0;		/* new debug level */
 
+	    /* XXX should this be response-rate limited? */
 #ifdef HAVE_LIBWRAP
 	    if (smtp_session_denied) {
 		if (out) {
@@ -940,6 +948,7 @@ receive_smtp(in, out)
 	    break;
 	}
 	case HELP_CMD:
+	    /* XXX should this be response-rate limited? */
 	    write_log(WRITE_LOG_SYS, "remote HELP: '%s' requested by %s%s%s%s%s%s%s%s%s",
 		      data,
 		      ident_sender ? ident_sender : "",
@@ -984,6 +993,7 @@ receive_smtp(in, out)
 	case OTHER_CMD: {
 	    static int logged_unknown = 0;
 
+	    /* XXX should this be response-rate limited? */
 	    if (out) {
 		fprintf(out, "500 5.5.1 Command unrecognized\r\n");
 		fflush(out);
@@ -1061,6 +1071,7 @@ do_greeting(out, ehlo_p, saddrp, shpp)
 
 #ifdef HAVE_LIBWRAP
     if (smtp_session_denied) {
+	/* XXX should this be response-rate limited? */
 	if (out) {
 	    /*
 	     * NOTE: do not include enhanced status codes (RFC1893) in the
@@ -1126,6 +1137,8 @@ do_greeting(out, ehlo_p, saddrp, shpp)
 	fatal = 0;
 	if (! (sender_host = verify_host(data, saddrp, shp, h_errno, &errstr, &fatal))) {
 	    if (fatal) {
+		/* XXX should this be response-rate limited? */
+
 		fprintf(out, "501-%s requires a valid host name as operand: '%s'\r\n",
 			ehlo_p ? "EHLO" : "HELO",
 			data);
@@ -1237,6 +1250,8 @@ send_session_denied_reply(out, cmd, param)
     char *cmd;
     char *param;
 {
+    /* XXX should this be response-rate limited? */
+
     fprintf(out, "550-5.5.1 You%s%s%s%s%s are not permitted to issue any more commands from [%s].\r\n",
 	    (sender_host_really || ident_sender) ? " (i.e. " : "",
 	    ident_sender ? ident_sender : "",
@@ -1276,6 +1291,8 @@ non_compliant_reply(out, ecode, estatus, errtxt)
     char *estatus;		/* enhanced status code (RFC1893) */
     char *errtxt;
 {
+    /* XXX should this be response-rate limited? */
+
 #ifdef LOG_SMTP_NON_COMPLIANCE
     write_log(WRITE_LOG_SYS, "sent %d-%s: '%s' to %s%s%s%s%s%s%s%s%s.",
 	      ecode,
@@ -1358,24 +1375,6 @@ reset_state()
     reset_hit_table();
 }
 
-static void
-reset_hit_table()
-{
-    struct hash *curh;		/* pointer to walk the table */
-
-    /* free the hash table elements */
-    for (curh = walk_hash((struct hash *) NULL, hit_table);
-	 curh;
-	 curh = walk_hash(curh, hit_table)) {
-	free_hash_element(curh, 0, hit_table); /* free without deletion */
-    }
-    free_hash_table(hit_table);
-    hit_table = new_hash_table(hit_table_len,
-			       hit_table_block,
-			       HASH_DEFAULT);
-    return;
-}
-
 static enum e_smtp_commands
 read_smtp_command(fp, out)
     register FILE *fp;			/* SMTP command stream */
@@ -1514,6 +1513,19 @@ decode_mail_options(rest, out)
 		return -1;
 	    }
 	    if (accepted_msg_size > 0 && body_size > accepted_msg_size) {
+#ifndef NO_LOG_SMTP_TOO_BIG
+		write_log(WRITE_LOG_SYS, "remote MAIL FROM: SIZE=%ld too big from %s%s%s%s%s%s%s%s%s.",
+			  body_size,
+			  ident_sender ? ident_sender : "",
+			  ident_sender ? "@" : "",
+			  sender_host ? sender_host : "",
+			  sender_host_really ? "(" : "",
+			  sender_host_really ? sender_host_really : "",
+			  sender_host_really ? ")" : "",
+			  sender_host_addr ? " [" : "",
+			  sender_host_addr ? sender_host_addr : "",
+			  sender_host_addr ? "]" : "");
+#endif
 		if (out) {
 #ifdef HAVE_DF_SPOOL
 		    /* XXX this might not be 100% right if short of spool space! */
@@ -1521,6 +1533,7 @@ decode_mail_options(rest, out)
 #else
 		    fprintf(out, "552-5.3.4 A message of %ld bytes is far too large!\r\n", (long) body_size);
 #endif
+		    /* NOTE: the remainder of this reply is identical in two places */
 		    fprintf(out, "552-5.3.4 Do NOT send files by e-mail!\r\n");
 		    fprintf(out, "552-5.3.4 If you are sending a MIME message please set your mailer so that it\r\n");
 		    fprintf(out, "552-5.3.4 splits messages larger than 64KB into muliple parts.\r\n");
