@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_110:string.c,v 1.29 1999/11/29 21:11:13 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_111:string.c,v 1.30 2000/02/14 05:31:31 woods Exp"
  */
 
 /*
@@ -581,9 +581,9 @@ base62(val)
 /*
  * read_line - read a line from an input stream and return a pointer to it
  *
- * Any trailing newline is stripped from the returned string.
+ * returns a storage area which may be reused for subsequent calls.
  *
- * returns a static area which may be reused after subsequent calls.
+ * returns NULL after EOF has been reached and nothing more can be read.
  */
 char *
 read_line(f)
@@ -600,8 +600,14 @@ read_line(f)
 	STR_CHECK(&line);
 	STR_CLEAR(&line);
     }
-    while ((c = getc(f)) != '\n' && c != EOF) {
+    while ((c = getc(f)) != EOF) {
 	STR_NEXT(&line, c);
+	if (c == '\n') {
+	    break;
+	}
+    }
+    if (STR_LEN(&line) == 0) {
+	return NULL;
     }
     STR_NEXT(&line, '\0');
     return STR(&line);
