@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_110:tcpsmtp.c,v 1.53 2000/02/06 16:45:19 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_111:tcpsmtp.c,v 1.54 2000/02/12 19:05:55 woods Exp"
  */
 
 /*
@@ -778,7 +778,8 @@ ip_address(remote_host, ipaddr, family, errorp)
 
         hostentp = gethostbyname(remote_host);
         if (hostentp == NULL) {
-	    *errorp = hstrerror(h_errno);
+	    /* XXX cast of hstrerror() is to explicitly discard const */
+	    *errorp = (char *) hstrerror(h_errno);
             return -1;
         }
         (void) memcpy((char *) ipaddr, hostentp->h_addr, (size_t) hostentp->h_length);
