@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/util:RELEASE-3_2_0_110:checkerr.sh,v 1.13 2000/02/07 15:27:03 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_111:checkerr.sh,v 1.14 2000/02/13 16:59:55 woods Exp"
 #
 #    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 #    Copyright (C) 1992  Ronald S. Karr
@@ -14,10 +14,20 @@
 # postmaster now, such as due to a configuration error, then try to
 # send it in a future invocation of this script.
 
+umask 022
+
 PATH="X_UTIL_PATH_X:X_SECURE_PATH_X"; export PATH
 SMAIL_PROGRAM="X_SMAIL_NAME_X"
 SPOOL_DIRS="`$SMAIL_PROGRAM -bP spool_dirs`"
 TMPDIR="X_TMP_DIR_X"
+if [ ! -d $TMPDIR ] ; then
+	if ! mkdir $TMPDIR ; then
+		echo "$0: $TMPDIR exists as a file!" 2>&1
+		exit 1
+	else
+		chmod 700 $TMPDIR
+	fi
+fi
 HOSTNAME="`$SMAIL_PROGRAM -bP primary_name`"
 LOGFILE="`$SMAIL_PROGRAM -bP logfile`"
 # Old fashioned smaillog form
