@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/util:RELEASE-3_2_0_110:smailbug.sh,v 1.5 1999/09/03 17:05:16 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_111:smailbug.sh,v 1.6 2000/02/13 17:17:28 woods Exp"
 #
 # Submit a problem report to a GNATS site.
 #
@@ -60,44 +60,79 @@ DEFAULT_ORGANIZATION="net"
 # What mailer to use.  This must come after the config file, since it is
 # host-dependent.
 if [ -f X_SMAIL_NAME_X ]; then
-  MAIL_AGENT="X_SMAIL_NAME_X -oi -t"
+	MAIL_AGENT="X_SMAIL_NAME_X -oi -t"
 elif [ -f /usr/sbin/sendmail ]; then
-  MAIL_AGENT="/usr/sbin/sendmail -oi -t"
+	MAIL_AGENT="/usr/sbin/sendmail -oi -t"
 else
-  MAIL_AGENT="/usr/lib/sendmail -oi -t"
+	MAIL_AGENT="/usr/lib/sendmail -oi -t"
 fi
 
 # How to read the passwd database.
 PASSWD="cat /etc/passwd"
 
+## if [ -z "$TMPDIR" ]; then
+## 	TMPDIR=/tmp
+## else
+## 	if [ "`echo $TMPDIR | grep '/$'`" != "" ]; then
+## 		TMPDIR="`echo $TMPDIR | sed -e 's,/$,,'`"
+## 	fi
+## fi
+TMPDIR="X_TMPDIR_X"
+if [ ! -d $TMPDIR ] ; then
+	if ! mkdir $TMPDIR ; then
+		echo "$0: $TMPDIR exists as a file!" 2>&1
+		exit 1
+	else
+		chmod 700 $TMPDIR
+	fi
+fi
+TEMP=$TMPDIR/p$$
+BAD=$TMPDIR/pbad$$
+REF=$TMPDIR/pf$$
+
+# Catch some signals. ($xs kludge needed by Sun /bin/sh)
+xs=0
+trap 'rm -f $BAD; exit $xs' 0
+trap 'echo "$COMMAND: Aborting ..."; rm -f $REF $TEMP ; exit' 1 2 3 13 15
+
 # XXX this "echo" determination is cut&paste from my .profile <woods@planix.com>
 HAVEPRINT=false ; export HAVEPRINT
-if expr "`type print`" : '^print is shell builtint$' >/dev/null 2>&1 ; then
+if expr "`type print`" : '^print is a shell builtin$' >/dev/null 2>&1 ; then
 	HAVEPRINT=true
 fi
 HAVEPRINTF=false ; export HAVEPRINTF
-if expr "`type printf`" : '^printf is shell builtint$' >/dev/null 2>&1 ; then
+if expr "`type printf`" : '^printf is a shell builtin$' >/dev/null 2>&1 ; then
 	HAVEPRINTF=true
 elif expr "`type printf`" : '.* is .*/printf$' >/dev/null 2>&1 ; then
 	HAVEPRINTF=true
 fi
+# always use ``$echo'' if any of the other variables are used...
+#	$nl - print a newline (always required at end of line if desired)
+#	$n - option to turn off final newline
+#	$c - escape sequence to turn off final newline
+# usage for a prompt is:
+#	$echo $n "prompt: $c"
+# and for a normal line
+#	$echo "message$nl"
+#
 if $HAVEPRINT ; then
 	# use ``$echo'' if any of the other variables...
 	echo=print
 	nl='\n'
-	n=''
-	c='\c'
+	n='-n'
+	# XXX in theory '\c' is equivalent of '-n' in most shells
+	c=''
 elif $HAVEPRINTF ; then
 	# use ``$echo'' if any of the other variables...
 	echo=printf
 	nl='\n'
 	n=''
-	c='\c'
+	c=''
 else
 	echo=echo
-	(echo "hi there\c" ; echo " ") >$HOME/echotmp
+	(echo "hi there\c" ; echo " ") >$TMPDIR/echotmp
 	# Configure checks to make sure grep returns a status...
-	if grep c $HOME/echotmp >/dev/null 2>&1 ; then
+	if grep c $TMPDIR/echotmp >/dev/null 2>&1 ; then
 		nl=''
 		n='-n'
 		c=''
@@ -106,23 +141,11 @@ else
 		n=''
 		c='\c'
 	fi
-	rm -f $HOME/echotmp
+	rm -f $TMPDIR/echotmp
 fi
 
 #
 
-if [ -z "$TMPDIR" ]; then
-  TMPDIR=/tmp
-else
-  if [ "`echo $TMPDIR | grep '/$'`" != "" ]; then
-    TMPDIR="`echo $TMPDIR | sed -e 's,/$,,'`"
-  fi
-fi
-
-TEMP=$TMPDIR/p$$
-BAD=$TMPDIR/pbad$$
-REF=$TMPDIR/pf$$
-
 # find a user name
 if [ "$LOGNAME" = "" ]; then
 	if [ "$USER" != "" ]; then
@@ -182,8 +205,7 @@ ARCH=`[ -f /bin/arch ] && /bin/arch`
 MACHINE=`[ -f /bin/machine ] && /bin/machine`
 
 COMMAND=`echo $0 | sed -e 's,.*/,,'`
-USAGE="Usage: $COMMAND [-PVL] [-t address] [-f filename] [--request-id] 
-[--version]"
+USAGE="Usage: $COMMAND [-PVL] [-f filename] [--version]"
 REMOVE=
 BATCH=
 
@@ -194,13 +216,13 @@ while [ $# -gt 0 ]; do
 ## 	shift ; GNATS_ADDR="$1"
 ## 	EXPLICIT_GNATS_ADDR=true
 ##         ;;
-##     -f | --file) if [ $# -eq 1 ]; then echo "$USAGE"; exit 1; fi
-## 	shift ; IN_FILE="$1"
-## 	if [ "$IN_FILE" != "-" -a ! -r "$IN_FILE" ]; then
-## 	  echo "$COMMAND: cannot read $IN_FILE"
-## 	  exit 1
-## 	fi
-## 	;;
+    -f | --file) if [ $# -eq 1 ]; then echo "$USAGE"; exit 1; fi
+	shift ; IN_FILE="$1"
+	if [ "$IN_FILE" != "-" -a ! -r "$IN_FILE" ]; then
+	  echo "$COMMAND: cannot read $IN_FILE"
+	  exit 1
+	fi
+	;;
     -b | --batch) BATCH=true ;;
     -p | -P | --print) PRINT=true ;;
     -L | --list) FORMAT=norm ;;
@@ -293,11 +315,6 @@ DESCRIPTION_C='<precise description of the problem (multiple lines)>'
 HOW_TO_REPEAT_C='<code/input/activities to reproduce the problem (multiple lines)>'
 FIX_C='<how to correct or work around the problem, if known (multiple lines)>'
 
-# Catch some signals. ($xs kludge needed by Sun /bin/sh)
-xs=0
-trap 'rm -f $REF $TEMP; exit $xs' 0
-trap 'echo "$COMMAND: Aborting ..."; rm -f $REF $TEMP; xs=1; exit' 1 2 3 13 15
-
 ## # If they told us to use a specific file, then do so.
 ## if [ -n "$IN_FILE" ]; then
 ##   if [ "$IN_FILE" = "-" ]; then
@@ -333,10 +350,10 @@ trap 'echo "$COMMAND: Aborting ..."; rm -f $REF $TEMP; xs=1; exit' 1 2 3 13 15
     for file in $TEMP $REF ; do
       cat  > $file << '__EOF__'
 SEND-PR: -*- send-pr -*-
-SEND-PR: Lines starting with `SEND-PR' will be removed automatically, as
-SEND-PR: will all comments (text enclosed in `<' and `>').
+SEND-PR: Lines starting with 'SEND-PR' will be removed automatically, as
+SEND-PR: will all comments (text enclosed in '<' and '>').
 SEND-PR: 
-SEND-PR: Please consult the send-pr man page `send-pr(1)' or the Texinfo
+SEND-PR: Please consult the send-pr man page 'send-pr(1)' or the Texinfo
 SEND-PR: manual if you are not sure how to fill out a problem report.
 SEND-PR:
 SEND-PR: Choose from the following categories:
@@ -395,16 +412,16 @@ __EOF__
   fi
 
   chmod u+w $TEMP
-  if [ -z "$REQUEST_ID" ]; then
+##   if [ -z "$REQUEST_ID" ]; then
     eval $EDIT $TEMP
-  else
-    ed -s $TEMP << '__EOF__'
-/^Subject/s/^Subject:.*/Subject: request for a customer id/
-/^>Category/s/^>Category:.*/>Category: send-pr/
-w
-q
-__EOF__
-  fi
+##   else
+##     ed -s $TEMP << '__EOF__'
+## /^Subject/s/^Subject:.*/Subject: request for a customer id/
+## /^>Category/s/^>Category:.*/>Category: send-pr/
+## w
+## q
+## __EOF__
+##  fi
 
   if cmp -s $REF $TEMP ; then
     echo "$COMMAND: problem report not filled out, therefore not sent"
